( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf gnome-applications.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-folder-generic.png gnome-applications.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf gok.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-application-generic.png gok.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf gnopernicus.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-application-generic.png gnopernicus.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf jDictionary.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-application-generic.png jDictionary.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf jEdit.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-application-generic.png jEdit.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf jGraphPad.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-application-generic.png jGraphPad.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf gthumb.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-application-generic.png gthumb.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf gnome-pdf.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-application-generic.png gnome-pdf.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf postscript-viewer.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-application-generic.png postscript-viewer.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf sun_java.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-application-generic.png sun_java.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf glow.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-application-generic.png glow.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf gaim.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-application-generic.png gaim.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf gnomemeeting-logo-icon.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-application-generic.png gnomemeeting-logo-icon.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf gtkam-camera.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-application-generic.png gtkam-camera.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf jmplay.48.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-application-generic.png jmplay.48.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf media-player-48.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-application-generic.png media-player-48.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf realplay.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-application-generic.png realplay.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf rp7.xpm )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-application-generic.png rp7.xpm )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf realplayer.xpm )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-application-generic.png realplayer.xpm )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf gnome-planner.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-application-generic.png gnome-planner.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf glade-2.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-application-generic.png glade-2.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf gnome-monitor.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-application-generic.png gnome-monitor.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf JUSimageIcon.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-application-generic.png JUSimageIcon.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf nb48x48.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-application-generic.png nb48x48.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf gataxx.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-joystick.png gataxx.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf gnome-blackjack.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-joystick.png gnome-blackjack.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf gnect-icon.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-joystick.png gnect-icon.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf gnotski-icon.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-joystick.png gnotski-icon.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf gnome-mahjongg.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-joystick.png gnome-mahjongg.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf gnome-gnomine.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-joystick.png gnome-gnomine.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf gnome-nibbles.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-joystick.png gnome-nibbles.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf gnome-gnobots2.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-joystick.png gnome-gnobots2.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf gnome-gsame.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-joystick.png gnome-gsame.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf gnome-stones.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-joystick.png gnome-stones.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf gnome-gtali.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-joystick.png gnome-gtali.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf gnome-gnotravex.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-joystick.png gnome-gnotravex.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf glines.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-joystick.png glines.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf iagno.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-joystick.png iagno.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf jSpiderIcon.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-joystick.png jSpiderIcon.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf gdm.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-system.png gdm.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf gnome-other.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-system.png gnome-other.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf gconf-editor.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-system.png gconf-editor.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf jDiskReport.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-system.png jDiskReport.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf procman.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-system.png procman.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf fsexam-icon.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-system.png fsexam-icon.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf acme-48.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf keyboard.png acme-48.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf gnome-settings-im.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf keyboard.png gnome-settings-im.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf screensaver.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-ccscreensaver.png screensaver.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf gnome-screensaver.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-ccscreensaver.png gnome-screensaver.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf password.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-application-generic.png password.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf gnome-palm.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-application-generic.png gnome-palm.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf gnome-remote-desktop.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-application-generic.png gnome-remote-desktop.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf stock_proxy.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-globe.png stock_proxy.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf gnome-folder.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-folder-generic.png gnome-folder.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf config-language.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf advanced-directory.png config-language.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf stock_timezone.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf advanced-directory.png stock_timezone.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf gnome-lockscreen.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf advanced-directory.png gnome-lockscreen.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf gnome-modem.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf advanced-directory.png gnome-modem.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf xsane.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf advanced-directory.png xsane.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf serviceconf.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-application-generic.png serviceconf.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf config-users.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf advanced-directory.png config-users.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf administration.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-application-generic.png administration.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf config-xfree.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf advanced-directory.png config-xfree.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf gnome-ftp.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf advanced-directory.png gnome-ftp.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf gnome-desktop-config.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf advanced-directory.png gnome-desktop-config.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf disks.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-application-generic.png disks.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf logviewer.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-application-generic.png logviewer.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf network.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-globe.png network.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf network-config.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-globe.png network-config.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf gnome-server-config.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-globe.png gnome-server-config.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf web-browser.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-globe.png web-browser.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf hwbrowser.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gdm.png hwbrowser.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf sound-capplet.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf gnome-settings-sound.png sound-capplet.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf evolution.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf evolution-1.4.png evolution.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf staroffice-writer.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf star.png staroffice-writer.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf staroffice-impress.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf star.png staroffice-impress.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; rm -rf staroffice-calc.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/apps ; ln -sf star.png staroffice-calc.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-audio-ac3.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-audio.png gnome-mime-audio-ac3.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-audio-x-pn-realaudio.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-audio.png gnome-mime-audio-x-pn-realaudio.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-audio-basic.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-audio.png gnome-mime-audio-basic.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-audio-x-s3m.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-audio.png gnome-mime-audio-x-s3m.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-audio-x-stm.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-audio.png gnome-mime-audio-x-stm.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-audio-x-aiff.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-audio.png gnome-mime-audio-x-aiff.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-audio-x-ulaw.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-audio.png gnome-mime-audio-x-ulaw.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-audio-x-it.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-audio.png gnome-mime-audio-x-it.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-audio-x-voc.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-audio.png gnome-mime-audio-x-voc.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-audio-midi.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-audio.png gnome-mime-audio-midi.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-audio-x-midi.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-audio.png gnome-mime-audio-x-midi.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-audio-x-wav.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-audio.png gnome-mime-audio-x-wav.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-audio-x-mod.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-audio.png gnome-mime-audio-x-mod.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-audio-x-xi.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-audio.png gnome-mime-audio-x-xi.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-audio-x-mp3.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-audio.png gnome-mime-audio-x-mp3.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-audio-x-xm.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-audio.png gnome-mime-audio-x-xm.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-image-bmp.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-bmp.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-image-x-portable-anymap.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-x-portable-anymap.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-image-gif.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-gif.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-image-x-portable-bitmap.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-x-portable-bitmap.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-image-ief.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-ief.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-image-x-portable-graymap.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-x-portable-graymap.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-image-jpeg.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-jpeg.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-image-x-portable-pixmap.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-x-portable-pixmap.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-image-x-psd.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-x-psd.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-image-png.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-png.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-image-x-rgb.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-x-rgb.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-image-svg.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-svg.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-image-svg+xml.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-svg+xml.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-image-x-tga.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-x-tga.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-image-tiff.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-tiff.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-image-x-xbitmap.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-x-xbitmap.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-image-x-3ds.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-x-3ds.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-image-x-xcf.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-x-xcf.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-image-x-applix-graphic.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-x-applix-graphic.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-image-x-xfig.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-x-xfig.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-image-x-cmu-raster.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-x-cmu-raster.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-image-x-xpixmap.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-x-xpixmap.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-image-x-lwo.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-x-lwo.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-image-x-xwindowdump.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-x-xwindowdump.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-image-x-lws.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-x-lws.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-video-mpeg.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-video.png gnome-mime-video-mpeg.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-video-x-ms-asf.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-video.png gnome-mime-video-x-ms-asf.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-video-x-msvideo.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-video.png gnome-mime-video-x-msvideo.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-video-quicktime.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-video.png gnome-mime-video-quicktime.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-video-x-ms-wmv.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-video.png gnome-mime-video-x-ms-wmv.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-font-afm.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-x-font.png gnome-mime-application-x-font-afm.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-x-font-afm.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-x-font.png gnome-mime-x-font-afm.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-font-bdf.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-x-font.png gnome-mime-application-x-font-bdf.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-font-linux-psf.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-x-font.png gnome-mime-application-x-font-linux-psf.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-font-pcf.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-x-font.png gnome-mime-application-x-font-pcf.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-font-sunos-news.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-x-font.png gnome-mime-application-x-font-sunos-news.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-font-ttf.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-x-font.png gnome-mime-application-x-font-ttf.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-text-css.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-css.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-text-x-literate-haskell.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-literate-haskell.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-text-html.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-html.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-text-x-lyx.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-lyx.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-text-x-makefile.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-makefile.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-text-x-authors.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-authors.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-text-xml.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-xml.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-text-x-c-header.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-c-header.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-text-x-chdr.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-chdr.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-text-x-patch.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-patch.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-text-x-copying.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-copying.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-text-x-perl.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-perl.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-text-x-c.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-c.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-text-x-csrc.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-csrc.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-text-x-c++.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-c++.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-text-x-c++src.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-c++src.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-text-x-readme.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-readme.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-text-x-credits.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-credits.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-text-x-sql.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-sql.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-text-x-haskell.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-haskell.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-text-x-install.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-install.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-text-x-java.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-java.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-text-x-csharp.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-csharp.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-text-x-scheme.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-scheme.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-text-x-tex.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-tex.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-text-x-vcalendar.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-vcalendar.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-text-x-vcard.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-vcard.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-arj.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-compressed.png gnome-mime-application-x-arj.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-bzip.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-compressed.png gnome-mime-application-x-bzip.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-compress.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-compressed.png gnome-mime-application-x-compress.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-compressed-tar.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-compressed.png gnome-mime-application-x-compressed-tar.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-tar.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-compressed.png gnome-mime-application-x-tar.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-deb.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-compressed.png gnome-mime-application-x-deb.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-e-theme.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-compressed.png gnome-mime-application-x-e-theme.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-bzip-compressed-tar.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-compressed.png gnome-mime-application-x-bzip-compressed-tar.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-gzip.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-compressed.png gnome-mime-application-x-gzip.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-rpm.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-compressed.png gnome-mime-application-x-rpm.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-package.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-compressed.png gnome-package.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-archive.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-compressed.png gnome-mime-application-x-archive.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-cpio-compressed.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-compressed.png gnome-mime-application-x-cpio-compressed.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-cpio.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-compressed.png gnome-mime-application-x-cpio.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-jar.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-compressed.png gnome-mime-application-x-jar.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-lha.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-compressed.png gnome-mime-application-x-lha.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-lhz.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-compressed.png gnome-mime-application-lhz.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-rar.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-compressed.png gnome-mime-application-x-rar.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-zip.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-compressed.png gnome-mime-application-zip.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-msword.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-msword.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-ogg.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-ogg.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-pdf.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-pdf.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-pgp-encrypted.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-pgp-encrypted.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-pgp-keys.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-pgp-keys.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-pgp.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-pgp.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-postscript.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-postscript.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-rhythmbox-effect.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-rhythmbox-effect.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-rhythmbox-playlist.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-rhythmbox-playlist.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-qif.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-qif.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-rtf.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-rtf.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-vnd.lotus-1-2-3.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-vnd.lotus-1-2-3.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-vnd.ms-excel.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-vnd.ms-excel.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-vnd.sun.xml.calc.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-vnd.sun.xml.calc.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-vnd.sun.xml.draw.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-vnd.sun.xml.draw.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-vnd.sun.xml.impress.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-vnd.sun.xml.impress.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-vnd.sun.xml.writer.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-vnd.sun.xml.writer.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-vnd.stardivision.calc.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-vnd.stardivision.calc.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-vnd.stardivision.impress.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-vnd.stardivision.impress.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-vnd.stardivision.writer.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-vnd.stardivision.writer.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-vnd.ms-powerpoint.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-vnd.ms-powerpoint.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-blender.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-blender.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-vnd.rn-realmedia.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-vnd.rn-realmedia.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-abiword.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-abiword.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-applix-spreadsheet.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-applix-spreadsheet.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-applix-word.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-applix-word.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-backup.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-backup.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-dc-rom.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-dc-rom.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-dia-diagram.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-dia-diagram.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-gameboy-rom.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-gameboy-rom.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-genesis-rom.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-genesis-rom.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-gnome-app-info.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-gnome-app-info.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-gnumeric.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-gnumeric.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-gtktalog.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-gtktalog.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-java-byte-code.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-java-byte-code.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-kde-app-info.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-kde-app-info.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-killustrator.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-killustrator.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-kpresenter.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-kpresenter.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-kspread.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-kspread.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-kword.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-kword.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-mrproject.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-mrproject.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-msx-rom.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-msx-rom.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-n64-rom.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-n64-rom.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-nes-rom.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-nes-rom.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-object-file.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-object-file.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-object.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-object.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-ogg.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-ogg.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-php.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-php.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-reject.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-reject.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-scheme.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-scheme.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-smil.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-smil.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-smil.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-smil.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-sms-rom.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-sms-rom.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-sql.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-sql.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-stuffit.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-stuffit.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-tex.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-tex.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-cd-image.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-cd-image.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-class-file.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-class-file.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-dvi.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-dvi.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-glade.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-glade.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-gnucash.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-gnucash.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-ipod-firmware.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-ipod-firmware.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-qw.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-qw.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-shockwave-flash.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-shockwave-flash.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-trash.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-trash.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-core.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application-x-core-file.png gnome-mime-application-x-core.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-sharedlib.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-library.png gnome-mime-application-x-sharedlib.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-shellscript.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application-x-executable.png gnome-mime-application-x-shellscript.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-text-x-csh.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application-x-executable.png gnome-mime-text-x-csh.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-text-x-sh.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application-x-executable.png gnome-mime-text-x-sh.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-text-x-zsh.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application-x-executable.png gnome-mime-text-x-zsh.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-text-x-python.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application-x-executable.png gnome-mime-text-x-python.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-python-bytecode.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application-x-executable.png gnome-mime-application-x-python-bytecode.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; rm -rf gnome-mime-application-x-python.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/mimetypes ; ln -sf gnome-mime-application-x-executable.png gnome-mime-application-x-python.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/filesystems ; rm -rf gnome-fs-nfs.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/filesystems ; ln -sf gnome-fs-share.png gnome-fs-nfs.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/filesystems ; rm -rf gnome-fs-smb.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/filesystems ; ln -sf gnome-fs-share.png gnome-fs-smb.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/filesystems ; rm -rf gnome-fs-ssh.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/filesystems ; ln -sf gnome-fs-share.png gnome-fs-ssh.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/filesystems ; rm -rf gnome-fs-web.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/filesystems ; ln -sf gnome-fs-share.png gnome-fs-web.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/filesystems ; rm -rf gnome-fs-ftp.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/filesystems ; ln -sf gnome-fs-share.png gnome-fs-ftp.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/filesystems ; rm -rf gnome-fs-directory-visiting.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/filesystems ; ln -sf gnome-fs-directory-accept.png gnome-fs-directory-visiting.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/filesystems ; rm -rf gnome-fs-loading-icon.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/filesystems ; ln -sf gnome-fs-regular.png gnome-fs-loading-icon.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/devices ; rm -rf gnome-dev-cdrom-audio.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/devices ; ln -sf gnome-dev-cdrom.png gnome-dev-cdrom-audio.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/devices ; rm -rf gnome-dev-dvd.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/devices ; ln -sf gnome-dev-cdrom.png gnome-dev-dvd.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/devices ; rm -rf gnome-dev-mouse-ball.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/devices ; ln -sf gnome-dev-mouse-optical.png gnome-dev-mouse-ball.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/devices ; rm -rf gnome-dev-jazdisk.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/devices ; ln -sf gnome-dev-floppy.png gnome-dev-jazdisk.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/devices ; rm -rf gnome-dev-zipdisk.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/devices ; ln -sf gnome-dev-floppy.png gnome-dev-zipdisk.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/devices ; rm -rf gnome-dev-removable.png )
( cd usr/share/icons/HighContrastLargePrint/48x48/devices ; ln -sf gnome-dev-harddisk.png gnome-dev-removable.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf gnome-applications.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-folder-generic.png gnome-applications.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf gok.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-application-generic.png gok.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf gnopernicus.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-application-generic.png gnopernicus.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf jDictionary.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-application-generic.png jDictionary.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf jEdit.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-application-generic.png jEdit.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf jGraphPad.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-application-generic.png jGraphPad.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf gthumb.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-application-generic.png gthumb.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf gnome-pdf.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-application-generic.png gnome-pdf.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf postscript-viewer.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-application-generic.png postscript-viewer.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf sun_java.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-application-generic.png sun_java.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf glow.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-application-generic.png glow.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf gaim.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-application-generic.png gaim.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf gnomemeeting-logo-icon.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-application-generic.png gnomemeeting-logo-icon.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf gtkam-camera.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-application-generic.png gtkam-camera.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf jmplay.48.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-application-generic.png jmplay.48.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf media-player-48.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-application-generic.png media-player-48.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf realplay.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-application-generic.png realplay.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf rp7.xpm )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-application-generic.png rp7.xpm )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf realplayer.xpm )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-application-generic.png realplayer.xpm )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf gnome-planner.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-application-generic.png gnome-planner.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf glade-2.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-application-generic.png glade-2.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf gnome-monitor.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-application-generic.png gnome-monitor.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf JUSimageIcon.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-application-generic.png JUSimageIcon.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf nb48x48.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-application-generic.png nb48x48.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf gataxx.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-joystick.png gataxx.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf gnome-blackjack.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-joystick.png gnome-blackjack.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf gnect-icon.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-joystick.png gnect-icon.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf gnotski-icon.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-joystick.png gnotski-icon.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf gnome-mahjongg.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-joystick.png gnome-mahjongg.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf gnome-gnomine.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-joystick.png gnome-gnomine.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf gnome-nibbles.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-joystick.png gnome-nibbles.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf gnome-gnobots2.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-joystick.png gnome-gnobots2.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf gnome-gsame.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-joystick.png gnome-gsame.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf gnome-stones.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-joystick.png gnome-stones.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf gnome-gtali.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-joystick.png gnome-gtali.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf gnome-gnotravex.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-joystick.png gnome-gnotravex.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf glines.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-joystick.png glines.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf iagno.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-joystick.png iagno.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf jSpiderIcon.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-joystick.png jSpiderIcon.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf gdm.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-system.png gdm.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf gnome-other.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-system.png gnome-other.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf gconf-editor.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-system.png gconf-editor.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf jDiskReport.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-system.png jDiskReport.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf procman.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-system.png procman.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf fsexam-icon.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-system.png fsexam-icon.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf acme-48.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf keyboard.png acme-48.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf gnome-settings-im.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf keyboard.png gnome-settings-im.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf screensaver.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-ccscreensaver.png screensaver.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf gnome-screensaver.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-ccscreensaver.png gnome-screensaver.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf password.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-application-generic.png password.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf gnome-palm.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-application-generic.png gnome-palm.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf gnome-remote-desktop.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-application-generic.png gnome-remote-desktop.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf stock_proxy.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-globe.png stock_proxy.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf gnome-folder.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-folder-generic.png gnome-folder.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf config-language.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf advanced-directory.png config-language.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf stock_timezone.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf advanced-directory.png stock_timezone.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf gnome-lockscreen.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf advanced-directory.png gnome-lockscreen.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf gnome-modem.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf advanced-directory.png gnome-modem.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf xsane.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf advanced-directory.png xsane.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf serviceconf.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-application-generic.png serviceconf.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf config-users.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf advanced-directory.png config-users.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf administration.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-application-generic.png administration.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf config-xfree.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf advanced-directory.png config-xfree.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf gnome-ftp.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf advanced-directory.png gnome-ftp.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf gnome-desktop-config.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf advanced-directory.png gnome-desktop-config.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf disks.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-application-generic.png disks.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf logviewer.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-application-generic.png logviewer.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf network.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-globe.png network.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf network-config.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-globe.png network-config.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf gnome-server-config.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-globe.png gnome-server-config.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf web-browser.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-globe.png web-browser.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf hwbrowser.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gdm.png hwbrowser.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf sound-capplet.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf gnome-settings-sound.png sound-capplet.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf evolution.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf evolution-1.4.png evolution.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf staroffice-writer.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf star.png staroffice-writer.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf staroffice-impress.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf star.png staroffice-impress.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; rm -rf staroffice-calc.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/apps ; ln -sf star.png staroffice-calc.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/devices ; rm -rf gnome-dev-cdrom-audio.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/devices ; ln -sf gnome-dev-cdrom.png gnome-dev-cdrom-audio.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/devices ; rm -rf gnome-dev-dvd.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/devices ; ln -sf gnome-dev-cdrom.png gnome-dev-dvd.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/devices ; rm -rf gnome-dev-mouse-ball.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/devices ; ln -sf gnome-dev-mouse-optical.png gnome-dev-mouse-ball.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/devices ; rm -rf gnome-dev-jazdisk.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/devices ; ln -sf gnome-dev-floppy.png gnome-dev-jazdisk.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/devices ; rm -rf gnome-dev-zipdisk.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/devices ; ln -sf gnome-dev-floppy.png gnome-dev-zipdisk.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/devices ; rm -rf gnome-dev-removable.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/devices ; ln -sf gnome-dev-harddisk.png gnome-dev-removable.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-audio-ac3.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-audio.png gnome-mime-audio-ac3.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-audio-x-pn-realaudio.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-audio.png gnome-mime-audio-x-pn-realaudio.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-audio-basic.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-audio.png gnome-mime-audio-basic.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-audio-x-s3m.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-audio.png gnome-mime-audio-x-s3m.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-audio-x-stm.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-audio.png gnome-mime-audio-x-stm.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-audio-x-aiff.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-audio.png gnome-mime-audio-x-aiff.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-audio-x-ulaw.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-audio.png gnome-mime-audio-x-ulaw.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-audio-x-it.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-audio.png gnome-mime-audio-x-it.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-audio-x-voc.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-audio.png gnome-mime-audio-x-voc.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-audio-midi.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-audio.png gnome-mime-audio-midi.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-audio-x-midi.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-audio.png gnome-mime-audio-x-midi.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-audio-x-wav.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-audio.png gnome-mime-audio-x-wav.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-audio-x-mod.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-audio.png gnome-mime-audio-x-mod.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-audio-x-xi.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-audio.png gnome-mime-audio-x-xi.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-audio-x-mp3.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-audio.png gnome-mime-audio-x-mp3.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-audio-x-xm.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-audio.png gnome-mime-audio-x-xm.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-image-bmp.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-bmp.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-image-x-portable-anymap.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-x-portable-anymap.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-image-gif.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-gif.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-image-x-portable-bitmap.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-x-portable-bitmap.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-image-ief.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-ief.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-image-x-portable-graymap.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-x-portable-graymap.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-image-jpeg.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-jpeg.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-image-x-portable-pixmap.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-x-portable-pixmap.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-image-x-psd.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-x-psd.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-image-png.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-png.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-image-x-rgb.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-x-rgb.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-image-svg.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-svg.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-image-svg+xml.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-svg+xml.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-image-x-tga.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-x-tga.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-image-tiff.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-tiff.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-image-x-xbitmap.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-x-xbitmap.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-image-x-3ds.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-x-3ds.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-image-x-xcf.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-x-xcf.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-image-x-applix-graphic.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-x-applix-graphic.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-image-x-xfig.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-x-xfig.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-image-x-cmu-raster.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-x-cmu-raster.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-image-x-xpixmap.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-x-xpixmap.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-image-x-lwo.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-x-lwo.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-image-x-xwindowdump.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-x-xwindowdump.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-image-x-lws.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-image.png gnome-mime-image-x-lws.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-video-mpeg.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-video.png gnome-mime-video-mpeg.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-video-x-ms-asf.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-video.png gnome-mime-video-x-ms-asf.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-video-x-msvideo.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-video.png gnome-mime-video-x-msvideo.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-video-quicktime.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-video.png gnome-mime-video-quicktime.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-video-x-ms-wmv.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-video.png gnome-mime-video-x-ms-wmv.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-font-afm.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-x-font.png gnome-mime-application-x-font-afm.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-x-font-afm.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-x-font.png gnome-mime-x-font-afm.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-font-bdf.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-x-font.png gnome-mime-application-x-font-bdf.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-font-linux-psf.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-x-font.png gnome-mime-application-x-font-linux-psf.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-font-pcf.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-x-font.png gnome-mime-application-x-font-pcf.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-font-sunos-news.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-x-font.png gnome-mime-application-x-font-sunos-news.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-font-ttf.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-x-font.png gnome-mime-application-x-font-ttf.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-text-css.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-css.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-text-x-literate-haskell.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-literate-haskell.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-text-html.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-html.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-text-x-lyx.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-lyx.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-text-x-makefile.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-makefile.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-text-x-authors.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-authors.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-text-xml.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-xml.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-text-x-c-header.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-c-header.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-text-x-chdr.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-chdr.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-text-x-patch.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-patch.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-text-x-copying.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-copying.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-text-x-perl.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-perl.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-text-x-c.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-c.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-text-x-csrc.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-csrc.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-text-x-c++.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-c++.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-text-x-c++src.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-c++src.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-text-x-readme.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-readme.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-text-x-credits.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-credits.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-text-x-sql.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-sql.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-text-x-haskell.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-haskell.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-text-x-install.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-install.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-text-x-java.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-java.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-text-x-csharp.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-csharp.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-text-x-scheme.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-scheme.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-text-x-tex.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-tex.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-text-x-vcalendar.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-vcalendar.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-text-x-vcard.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-text.png gnome-mime-text-x-vcard.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-arj.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-compressed.png gnome-mime-application-x-arj.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-bzip.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-compressed.png gnome-mime-application-x-bzip.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-compress.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-compressed.png gnome-mime-application-x-compress.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-compressed-tar.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-compressed.png gnome-mime-application-x-compressed-tar.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-tar.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-compressed.png gnome-mime-application-x-tar.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-deb.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-compressed.png gnome-mime-application-x-deb.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-e-theme.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-compressed.png gnome-mime-application-x-e-theme.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-bzip-compressed-tar.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-compressed.png gnome-mime-application-x-bzip-compressed-tar.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-gzip.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-compressed.png gnome-mime-application-x-gzip.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-rpm.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-compressed.png gnome-mime-application-x-rpm.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-package.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-compressed.png gnome-package.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-archive.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-compressed.png gnome-mime-application-x-archive.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-cpio-compressed.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-compressed.png gnome-mime-application-x-cpio-compressed.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-cpio.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-compressed.png gnome-mime-application-x-cpio.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-jar.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-compressed.png gnome-mime-application-x-jar.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-lha.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-compressed.png gnome-mime-application-x-lha.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-lhz.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-compressed.png gnome-mime-application-lhz.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-rar.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-compressed.png gnome-mime-application-x-rar.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-zip.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-compressed.png gnome-mime-application-zip.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-msword.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-msword.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-ogg.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-ogg.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-pdf.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-pdf.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-pgp-encrypted.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-pgp-encrypted.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-pgp-keys.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-pgp-keys.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-pgp.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-pgp.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-postscript.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-postscript.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-rhythmbox-effect.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-rhythmbox-effect.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-rhythmbox-playlist.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-rhythmbox-playlist.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-qif.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-qif.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-rtf.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-rtf.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-vnd.lotus-1-2-3.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-vnd.lotus-1-2-3.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-vnd.ms-excel.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-vnd.ms-excel.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-vnd.sun.xml.calc.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-vnd.sun.xml.calc.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-vnd.sun.xml.draw.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-vnd.sun.xml.draw.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-vnd.sun.xml.impress.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-vnd.sun.xml.impress.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-vnd.sun.xml.writer.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-vnd.sun.xml.writer.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-vnd.stardivision.calc.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-vnd.stardivision.calc.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-vnd.stardivision.impress.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-vnd.stardivision.impress.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-vnd.stardivision.writer.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-vnd.stardivision.writer.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-vnd.ms-powerpoint.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-vnd.ms-powerpoint.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-blender.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-blender.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-vnd.rn-realmedia.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-vnd.rn-realmedia.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-abiword.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-abiword.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-applix-spreadsheet.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-applix-spreadsheet.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-applix-word.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-applix-word.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-backup.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-backup.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-dc-rom.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-dc-rom.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-dia-diagram.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-dia-diagram.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-gameboy-rom.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-gameboy-rom.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-genesis-rom.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-genesis-rom.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-gnome-app-info.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-gnome-app-info.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-gnumeric.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-gnumeric.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-gtktalog.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-gtktalog.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-java-byte-code.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-java-byte-code.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-kde-app-info.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-kde-app-info.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-killustrator.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-killustrator.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-kpresenter.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-kpresenter.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-kspread.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-kspread.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-kword.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-kword.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-mrproject.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-mrproject.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-msx-rom.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-msx-rom.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-n64-rom.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-n64-rom.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-nes-rom.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-nes-rom.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-object-file.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-object-file.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-object.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-object.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-ogg.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-ogg.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-php.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-php.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-reject.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-reject.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-scheme.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-scheme.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-smil.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-smil.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-smil.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-smil.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-sms-rom.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-sms-rom.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-sql.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-sql.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-stuffit.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-stuffit.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-tex.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-tex.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-cd-image.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-cd-image.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-class-file.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-class-file.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-dvi.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-dvi.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-glade.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-glade.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-gnucash.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-gnucash.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-ipod-firmware.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-ipod-firmware.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-qw.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-qw.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-shockwave-flash.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-shockwave-flash.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-trash.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application.png gnome-mime-application-x-trash.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-core.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application-x-core-file.png gnome-mime-application-x-core.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-sharedlib.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-library.png gnome-mime-application-x-sharedlib.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-shellscript.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application-x-executable.png gnome-mime-application-x-shellscript.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-text-x-csh.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application-x-executable.png gnome-mime-text-x-csh.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-text-x-sh.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application-x-executable.png gnome-mime-text-x-sh.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-text-x-zsh.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application-x-executable.png gnome-mime-text-x-zsh.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-text-x-python.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application-x-executable.png gnome-mime-text-x-python.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-python-bytecode.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application-x-executable.png gnome-mime-application-x-python-bytecode.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; rm -rf gnome-mime-application-x-python.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/mimetypes ; ln -sf gnome-mime-application-x-executable.png gnome-mime-application-x-python.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/filesystems ; rm -rf gnome-fs-nfs.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/filesystems ; ln -sf gnome-fs-share.png gnome-fs-nfs.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/filesystems ; rm -rf gnome-fs-smb.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/filesystems ; ln -sf gnome-fs-share.png gnome-fs-smb.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/filesystems ; rm -rf gnome-fs-ssh.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/filesystems ; ln -sf gnome-fs-share.png gnome-fs-ssh.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/filesystems ; rm -rf gnome-fs-web.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/filesystems ; ln -sf gnome-fs-share.png gnome-fs-web.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/filesystems ; rm -rf gnome-fs-ftp.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/filesystems ; ln -sf gnome-fs-share.png gnome-fs-ftp.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/filesystems ; rm -rf gnome-fs-directory-visiting.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/filesystems ; ln -sf gnome-fs-directory-accept.png gnome-fs-directory-visiting.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/filesystems ; rm -rf gnome-fs-loading-icon.png )
( cd usr/share/icons/HighContrastLargePrintInverse/48x48/filesystems ; ln -sf gnome-fs-regular.png gnome-fs-loading-icon.png )

for i in Crux Flat-Blue Sandy Smokey-Blue Smokey-Red HighContrast \
	LargePrint LowContrastLargePrint HighContrastLargePrint \
	LowContrast HighContrastLargePrintInverse HighContrastInverse
do
    if [ -e usr/share/icons/$i/icon-theme.cache ]; then
        rm -f usr/share/icons/$i/icon-theme.cache
    fi
	usr/bin/gtk-update-icon-cache usr/share/icons/$i
done

